@@ -4,6 +4,7 @@ pub use app::*;
 pub mod address;
 pub mod asm;
 pub mod commands;
+pub mod comments;
 pub mod cursor_position;
 pub mod data;
 pub mod events;
@@ -16,6 +17,7 @@ pub mod info_mode;
 pub mod instruction;
 pub mod log;
 pub mod mockup;
+pub mod pane;
 pub mod plugins;
 pub mod popup;
 pub mod settings;
